Crusade: Barcelona Barcelona, Spain September 10th 2000 30 players Ginés Quiñonero-Santiago https://groups.google.com/forum/#!msg/rec.games.trading-cards.jyhad/ZKxcKotE24k/AhP9-S4v9_0J VENTRUE HOSTILITIES Crypt (12 cards, min=15, max=40, avg=7.08) ------------------------------------------ 1x Arika 11 DOM FOR OBF PRE aus cel inner circle Ventrue:2 1x Democritus 10 DOM PRE aus cel for justicar Ventrue:1 1x Queen Anne 10 DOM FOR PRE aus obf prince Ventrue:2 1x Wilhelm Waldburg 9 DOM FOR PRE aus cel prince Ventrue:2 1x Anson 8 CEL PRE aus dom prince Toreador:1 1x Emerson Bridges 8 DOM FOR PRE pot prince Ventrue:1 1x Sir Walter Nash 7 DOM FOR PRE prince Ventrue:1 1x Timothy Crowley 7 FOR PRE ani dom prince Ventrue:1 1x Rake 6 PRE aus cel pot prince Brujah:1 1x Violette Prentiss 4 PRE dom Ventrue:1 1x Roland Loussarian 3 for pre Ventrue:1 1x Rufina Soledad 2 for Ventrue:1 Library (90 cards) Master (14) 2x Blood Doll 1x Direct Intervention 1x Elysium: The Arboretum 1x Elysium: The Palace of Versailles 2x Fortitude 3x Hostile Takeover 1x Secure Haven 1x Sudden Reversal 1x Uptown Hunting Ground 1x Ventrue Headquarters Action (12) 2x Atonement 3x Embrace, The 1x Far Mastery 6x Govern the Unaligned Equipment (2) 1x IR Goggles 1x Ivory Bow Political Action (15) 4x Banishment 4x Consanguineous Boon 1x Domain Challenge 5x Kine Resources Contested 1x Parity Shift Action Modifier (14) 4x Awe 2x Daring the Dawn 5x Freak Drive 1x Kiss of Ra, The 2x Voter Captivation Reaction (20) 10x Deflection 3x Forced Awakening 7x Second Tradition: Domain Combat (13) 11x Majesty 2x Skin of Steel